@@ -3,7 +3,7 @@
 ArgConfig &ArgConfig::instance()
 {
     if (!s_argconfig)
-        throw Errno("ArgConfig::instance(): not yet initialized");
+        throw Exception{} << "ArgConfig::instance(): not yet initialized";
 
     return *s_argconfig;
 }
